@@ -57,12 +57,15 @@ class CallAvoidCheckingToContinueAnalyzer(BaseAnalyzer):
                 if isinstance(node.value, ast.Call):
                     return True
                 else:
-                    self.assignments_from_calls.pop(node.targets[0].id, None)
+                    if hasattr(node.targets[0], "id"):
+                        self.assignments_from_calls.pop(node.targets[0].id, None)
             return False
 
         raw_assignments = [stm for stm in node.body if is_assigned_from_call(stm)]
         # TODO: What if there's more targets?
-        assignments = {raw.targets[0].id: raw for raw in raw_assignments}
+        assignments = {
+            raw.targets[0].id: raw for raw in raw_assignments if hasattr(raw.targets[0], "id")
+        }
         self.assignments_from_calls.update(assignments)
 
     def _find_violations(self, node: StmtBodyProtocol):
@@ -83,25 +86,27 @@ class CallAvoidCheckingToContinueAnalyzer(BaseAnalyzer):
             test = if_stmt.test
             if isinstance(test, ast.Name):
                 if assignment := self.assignments_from_calls.get(test.id):
-                    callable_name = assignment.value.func.id
-                    msg = rawmsg.format(callable_name)
-                    self.violations.append(
-                        Violation(code, if_stmt.lineno, if_stmt.col_offset, msg, self.filename)
-                    )
-            elif isinstance(test, ast.UnaryOp):
-                if isinstance(test.operand, ast.Name):
-                    if assignment := self.assignments_from_calls.get(test.operand.id):
+                    if hasattr(assignment.value.func, "id"):
                         callable_name = assignment.value.func.id
                         msg = rawmsg.format(callable_name)
                         self.violations.append(
-                            Violation(
-                                code,
-                                if_stmt.lineno,
-                                if_stmt.col_offset,
-                                msg,
-                                self.filename,
-                            )
+                            Violation(code, if_stmt.lineno, if_stmt.col_offset, msg, self.filename)
                         )
+            elif isinstance(test, ast.UnaryOp):
+                if isinstance(test.operand, ast.Name):
+                    if assignment := self.assignments_from_calls.get(test.operand.id):
+                        if hasattr(assignment.value.func, "id"):
+                            callable_name = assignment.value.func.id
+                            msg = rawmsg.format(callable_name)
+                            self.violations.append(
+                                Violation(
+                                    code,
+                                    if_stmt.lineno,
+                                    if_stmt.col_offset,
+                                    msg,
+                                    self.filename,
+                                )
+                            )
 
     def _scan_deeper(self, node: StmtBodyProtocol, may_contain_violations: bool):
         self._scan_assignments(node)
@@ -109,9 +114,10 @@ class CallAvoidCheckingToContinueAnalyzer(BaseAnalyzer):
         if may_contain_violations:
             self._find_violations(node)
         else:
-            *_, last_stm = node.body
-            if isinstance(last_stm, ast.Return):
-                may_contain_violations = True
+            if node.body:
+                *_, last_stm = node.body
+                if isinstance(last_stm, ast.Return):
+                    may_contain_violations = True
 
         for child in node.body:
             if hasattr(child, "body"):
